# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\SAVIOUR\Desktop\untitled.ui'
#
# Created: Sun Sep 02 13:02:23 2012
#      by: PyQt5 UI code generator 4.8.4
#
# WARNING! All changes made in this file will be lost!
import os
from gui.main_window import font_size
from PyQt5 import QtCore, QtWidgets, QtGui

font_setting = font_size()

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_attack_panel(object):
    def setupUi(self, attack_panel):
        attack_panel.setObjectName(_fromUtf8("attack_panel"))
        attack_panel.resize(762, 549)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/wifi_4.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        attack_panel.setWindowIcon(icon)
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(attack_panel)
        self.verticalLayout_13.setObjectName(_fromUtf8("verticalLayout_13"))
        self.general_group_box = QtWidgets.QGroupBox(attack_panel)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.general_group_box.setFont(font)
        self.general_group_box.setTitle(_fromUtf8(""))
        self.general_group_box.setObjectName(_fromUtf8("general_group_box"))
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.general_group_box)
        self.verticalLayout_12.setObjectName(_fromUtf8("verticalLayout_12"))
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.groupBox_2 = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox_2.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setAlignment(QtCore.Qt.AlignCenter)
        self.groupBox_2.setFlat(True)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.ap_listwidget = QtWidgets.QListWidget(self.groupBox_2)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Segoe UI"))
        font.setPointSize(9)
        self.ap_listwidget.setFont(font)
        self.ap_listwidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectItems)
        self.ap_listwidget.setMovement(QtWidgets.QListView.Snap)
        self.ap_listwidget.setSpacing(12)
        self.ap_listwidget.setViewMode(QtWidgets.QListView.IconMode)
        self.ap_listwidget.setObjectName(_fromUtf8("ap_listwidget"))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("../Documents/Projects/SVN Projects/Fern-Wifi-Cracker/resources/radio-wireless-signal-icone-5919-96.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item = QtWidgets.QListWidgetItem(self.ap_listwidget)
        item.setIcon(icon1)
        item = QtWidgets.QListWidgetItem(self.ap_listwidget)
        item.setIcon(icon1)
        self.verticalLayout_9.addWidget(self.ap_listwidget)
        spacerItem = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_9.addItem(spacerItem)
        self.line = QtWidgets.QFrame(self.groupBox_2)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.verticalLayout_9.addWidget(self.line)
        self.horizontalLayout_7.addWidget(self.groupBox_2)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.attack_button = QtWidgets.QPushButton(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.attack_button.setFont(font)
        self.attack_button.setIcon(icon)
        self.attack_button.setIconSize(QtCore.QSize(28, 27))
        self.attack_button.setObjectName(_fromUtf8("attack_button"))
        self.verticalLayout_2.addWidget(self.attack_button)
        self.automate_checkbox = QtWidgets.QCheckBox(self.general_group_box)
        self.automate_checkbox.setObjectName(_fromUtf8("automate_checkbox"))
        self.verticalLayout_2.addWidget(self.automate_checkbox)
        spacerItem2 = QtWidgets.QSpacerItem(20, 50, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem2)
        self.horizontalLayout_7.addLayout(self.verticalLayout_2)
        self.verticalLayout_12.addLayout(self.horizontalLayout_7)
        self.groupBox = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        spacerItem3 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem3)
        self.label_9 = QtWidgets.QLabel(self.groupBox)
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.horizontalLayout_6.addWidget(self.label_9)
        self.essid_label = QtWidgets.QLabel(self.groupBox)
        self.essid_label.setObjectName(_fromUtf8("essid_label"))
        self.horizontalLayout_6.addWidget(self.essid_label)
        spacerItem4 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem4)
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.horizontalLayout_6.addWidget(self.label_10)
        self.bssid_label = QtWidgets.QLabel(self.groupBox)
        self.bssid_label.setObjectName(_fromUtf8("bssid_label"))
        self.horizontalLayout_6.addWidget(self.bssid_label)
        spacerItem5 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem5)
        self.label_11 = QtWidgets.QLabel(self.groupBox)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.horizontalLayout_6.addWidget(self.label_11)
        self.channel_label = QtWidgets.QLabel(self.groupBox)
        self.channel_label.setObjectName(_fromUtf8("channel_label"))
        self.horizontalLayout_6.addWidget(self.channel_label)
        spacerItem6 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem6)
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setObjectName(_fromUtf8("label_12"))
        self.horizontalLayout_6.addWidget(self.label_12)
        self.power_label = QtWidgets.QLabel(self.groupBox)
        self.power_label.setObjectName(_fromUtf8("power_label"))
        self.horizontalLayout_6.addWidget(self.power_label)
        spacerItem7 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem7)
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.horizontalLayout_6.addWidget(self.label_13)
        self.encrypt_wep_label = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.encrypt_wep_label.setFont(font)
        self.encrypt_wep_label.setObjectName(_fromUtf8("encrypt_wep_label"))
        self.horizontalLayout_6.addWidget(self.encrypt_wep_label)
        spacerItem8 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem8)
        self.wps_support_label = QtWidgets.QLabel(self.groupBox)
        self.wps_support_label.setEnabled(False)
        self.wps_support_label.setObjectName(_fromUtf8("wps_support_label"))
        self.horizontalLayout_6.addWidget(self.wps_support_label)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem9)
        self.verticalLayout_11.addLayout(self.horizontalLayout_6)
        self.verticalLayout_12.addWidget(self.groupBox)
        self.groupBox_3 = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox_3.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_3.setFont(font)
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_3)
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem10)
        self.regular_attack_radio = QtWidgets.QRadioButton(self.groupBox_3)
        self.regular_attack_radio.setChecked(True)
        self.regular_attack_radio.setObjectName(_fromUtf8("regular_attack_radio"))
        self.horizontalLayout_4.addWidget(self.regular_attack_radio)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem11)
        self.wps_attack_radio = QtWidgets.QRadioButton(self.groupBox_3)
        self.wps_attack_radio.setObjectName(_fromUtf8("wps_attack_radio"))
        self.horizontalLayout_4.addWidget(self.wps_attack_radio)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem12)
        self.horizontalLayout_5.addLayout(self.horizontalLayout_4)
        self.verticalLayout_12.addWidget(self.groupBox_3)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.associate_label = QtWidgets.QLabel(self.general_group_box)
        self.associate_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.associate_label.setFont(font)
        self.associate_label.setObjectName(_fromUtf8("associate_label"))
        self.verticalLayout_5.addWidget(self.associate_label)
        self.injecting_label = QtWidgets.QLabel(self.general_group_box)
        self.injecting_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.injecting_label.setFont(font)
        self.injecting_label.setObjectName(_fromUtf8("injecting_label"))
        self.verticalLayout_5.addWidget(self.injecting_label)
        self.gathering_label = QtWidgets.QLabel(self.general_group_box)
        self.gathering_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.gathering_label.setFont(font)
        self.gathering_label.setObjectName(_fromUtf8("gathering_label"))
        self.verticalLayout_5.addWidget(self.gathering_label)
        self.cracking_label_2 = QtWidgets.QLabel(self.general_group_box)
        self.cracking_label_2.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cracking_label_2.setFont(font)
        self.cracking_label_2.setObjectName(_fromUtf8("cracking_label_2"))
        self.verticalLayout_5.addWidget(self.cracking_label_2)
        self.finished_label = QtWidgets.QLabel(self.general_group_box)
        self.finished_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.finished_label.setFont(font)
        self.finished_label.setObjectName(_fromUtf8("finished_label"))
        self.verticalLayout_5.addWidget(self.finished_label)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        spacerItem13 = QtWidgets.QSpacerItem(248, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem13)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        spacerItem14 = QtWidgets.QSpacerItem(200, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_6.addItem(spacerItem14)
        self.verticalLayout_10 = QtWidgets.QVBoxLayout()
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.injection_work_label_2 = QtWidgets.QLabel(self.general_group_box)
        self.injection_work_label_2.setEnabled(False)
        self.injection_work_label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.injection_work_label_2.setObjectName(_fromUtf8("injection_work_label_2"))
        self.horizontalLayout_8.addWidget(self.injection_work_label_2)
        self.dictionary_set = QtWidgets.QPushButton(self.general_group_box)
        self.dictionary_set.setObjectName(_fromUtf8("dictionary_set"))
        self.horizontalLayout_8.addWidget(self.dictionary_set)
        self.verticalLayout_10.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.attack_type_combo = QtWidgets.QComboBox(self.general_group_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.attack_type_combo.sizePolicy().hasHeightForWidth())
        self.attack_type_combo.setSizePolicy(sizePolicy)
        self.attack_type_combo.setAutoFillBackground(False)
        self.attack_type_combo.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContentsOnFirstShow)
        self.attack_type_combo.setDuplicatesEnabled(False)
        self.attack_type_combo.setObjectName(_fromUtf8("attack_type_combo"))
        self.horizontalLayout_2.addWidget(self.attack_type_combo)
        spacerItem15 = QtWidgets.QSpacerItem(13, 30, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.horizontalLayout_2.addItem(spacerItem15)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_2)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.horizontalLayout_9.addItem(spacerItem16)
        self.verticalLayout_10.addLayout(self.horizontalLayout_9)
        self.verticalLayout_6.addLayout(self.verticalLayout_10)
        self.horizontalLayout_10.addLayout(self.verticalLayout_6)
        self.verticalLayout_7.addLayout(self.horizontalLayout_10)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.ivs_progress_label = QtWidgets.QLabel(self.general_group_box)
        self.ivs_progress_label.setEnabled(False)
        self.ivs_progress_label.setAlignment(QtCore.Qt.AlignCenter)
        self.ivs_progress_label.setObjectName(_fromUtf8("ivs_progress_label"))
        self.verticalLayout_4.addWidget(self.ivs_progress_label)
        self.progressBar = QtWidgets.QProgressBar(self.general_group_box)
        self.progressBar.setProperty(_fromUtf8("value"), 24)
        self.progressBar.setTextVisible(False)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.verticalLayout_4.addWidget(self.progressBar)
        self.verticalLayout_7.addLayout(self.verticalLayout_4)
        self.horizontalLayout_3.addLayout(self.verticalLayout_7)
        self.verticalLayout_8.addLayout(self.horizontalLayout_3)
        spacerItem17 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_8.addItem(spacerItem17)
        self.verticalLayout_12.addLayout(self.verticalLayout_8)
        self.keys_cracked_label = QtWidgets.QLabel(self.general_group_box)
        self.keys_cracked_label.setAlignment(QtCore.Qt.AlignCenter)
        self.keys_cracked_label.setObjectName(_fromUtf8("keys_cracked_label"))
        self.verticalLayout_12.addWidget(self.keys_cracked_label)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.wps_pin_label = QtWidgets.QLabel(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.wps_pin_label.setFont(font)
        self.wps_pin_label.setAlignment(QtCore.Qt.AlignCenter)
        self.wps_pin_label.setObjectName(_fromUtf8("wps_pin_label"))
        self.verticalLayout.addWidget(self.wps_pin_label)
        self.key_label = QtWidgets.QLabel(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.key_label.setFont(font)
        self.key_label.setAlignment(QtCore.Qt.AlignCenter)
        self.key_label.setObjectName(_fromUtf8("key_label"))
        self.verticalLayout.addWidget(self.key_label)
        self.verticalLayout_12.addLayout(self.verticalLayout)
        self.verticalLayout_13.addWidget(self.general_group_box)

        self.retranslateUi(attack_panel)
        QtCore.QMetaObject.connectSlotsByName(attack_panel)

    def retranslateUi(self, attack_panel):
        attack_panel.setWindowTitle(QtWidgets.QApplication.translate("attack_panel", "Attack Panel", None, 0))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("attack_panel", "Select Target Access Point", None, 0))
        self.ap_listwidget.setSortingEnabled(True)
        __sortingEnabled = self.ap_listwidget.isSortingEnabled()
        self.ap_listwidget.setSortingEnabled(False)
        self.ap_listwidget.item(0).setText(QtWidgets.QApplication.translate("attack_panel", "Babarere", None, 0))
        self.ap_listwidget.item(1).setText(QtWidgets.QApplication.translate("attack_panel", "SwiftNG", None, 0))
        self.ap_listwidget.setSortingEnabled(__sortingEnabled)
        self.attack_button.setText(QtWidgets.QApplication.translate("attack_panel", "Attack", None, 0))
        self.automate_checkbox.setToolTip(QtWidgets.QApplication.translate("attack_panel", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Attack all Access points within range</p></body></html>", None, 0))
        self.automate_checkbox.setText(QtWidgets.QApplication.translate("attack_panel", "Automate", None, 0))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("attack_panel", "Access Point Details", None, 0))
        self.label_9.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>ESSID:</b></font>", None, 0))
        self.essid_label.setText(QtWidgets.QApplication.translate("attack_panel", " Babarere", None, 0))
        self.label_10.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>BSSID:</b></font>", None, 0))
        self.bssid_label.setText(QtWidgets.QApplication.translate("attack_panel", "00:CA:30:34:DF:F9", None, 0))
        self.label_11.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Channel:</b></font>", None, 0))
        self.channel_label.setText(QtWidgets.QApplication.translate("attack_panel", "1", None, 0))
        self.label_12.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Power:</b></font>", None, 0))
        self.power_label.setText(QtWidgets.QApplication.translate("attack_panel", "-67", None, 0))
        self.label_13.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Encryption:</b></font>", None, 0))
        self.encrypt_wep_label.setText(QtWidgets.QApplication.translate("attack_panel", "WEP", None, 0))
        self.wps_support_label.setText(QtWidgets.QApplication.translate("attack_panel", "Supports WPS", None, 0))
        self.groupBox_3.setTitle(QtWidgets.QApplication.translate("attack_panel", "Attack Option", None, 0))
        self.regular_attack_radio.setText(QtWidgets.QApplication.translate("attack_panel", "Regular Attack", None, 0))
        self.wps_attack_radio.setText(QtWidgets.QApplication.translate("attack_panel", "WPS  Attack", None, 0))
        self.associate_label.setText(QtWidgets.QApplication.translate("attack_panel", "Associating with Access Point", None, 0))
        self.injecting_label.setText(QtWidgets.QApplication.translate("attack_panel", "Gathering Packets", None, 0))
        self.gathering_label.setText(QtWidgets.QApplication.translate("attack_panel", "Packet Injection Status", None, 0))
        self.cracking_label_2.setText(QtWidgets.QApplication.translate("attack_panel", "Cracking Encryption", None, 0))
        self.finished_label.setText(QtWidgets.QApplication.translate("attack_panel", "Finished", None, 0))
        self.injection_work_label_2.setText(QtWidgets.QApplication.translate("attack_panel", "Injection Capability Status", None, 0))
        self.dictionary_set.setText(QtWidgets.QApplication.translate("attack_panel", "Browse", None, 0))
        self.ivs_progress_label.setText(QtWidgets.QApplication.translate("attack_panel", "IVS status", None, 0))
        self.keys_cracked_label.setText(QtWidgets.QApplication.translate("attack_panel", "2 Keys Cracked", None, 0))
        self.wps_pin_label.setText(QtWidgets.QApplication.translate("attack_panel", "WPS PIN: 192345673", None, 0))
        self.key_label.setText(QtWidgets.QApplication.translate("attack_panel", "WEP KEY: 1234567890", None, 0))




#-------------------------------------------------------------------------------
# Name:        Mozilla Cookies Engine
# Purpose:     Mozilla Firefox Cookie Engine
#
# Author:      Saviour Emmanuel Ekiko
#
# Created:     20/07/2012
# Copyright:   (c) Fern Wifi Cracker 2012
# Licence:     <GNU GPL v3>
#
#
#-------------------------------------------------------------------------------
# GNU GPL v3 Licence Summary:
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.


import os
import time
import sqlite3
import subprocess


# CREATE TABLE moz_cookies (id INTEGER PRIMARY KEY, baseDomain TEXT, name TEXT, value TEXT, host TEXT, path TEXT, expiry INTEGER, lastAccessed INTEGER, creationTime INTEGER, isSecure INTEGER, isHttpOnly INTEGER, CONSTRAINT moz_uniqueid UNIQUE (name, host, path))

class Mozilla_Cookie_Core(object):
    def __init__(self):
        self.isdeleted = False
        self.cookie_database = str()             # /root/.mozilla/firefox/nq474mcm.default/cookies.sqlite (Use self.get_Cookie_Path() to file path)

    def _create_moz_cookies(self):
        sql_code = "CREATE TABLE moz_cookies (id INTEGER PRIMARY KEY, baseDomain TEXT, name TEXT, value TEXT, host TEXT, path TEXT, expiry INTEGER, lastAccessed INTEGER, creationTime INTEGER, isSecure INTEGER, isHttpOnly INTEGER)"
        mozilla_cookie_db = sqlite3.connect(self.cookie_database)
        mozilla_cursor = mozilla_cookie_db.cursor()
        mozilla_cursor.execute(sql_code)
        mozilla_cookie_db.commit()
        mozilla_cookie_db.close()


    def _check_database_compatibility(self):
        if(self.isdeleted == False):
            self.kill_Process("firefox-bin")
            os.remove(self.cookie_database)
            self._create_moz_cookies()
            self.isdeleted = True



    def execute_query(self,sql_statement):
        '''Executes raw query into database and returns entry
            list() if any'''
        self._check_database_compatibility()
        mozilla_cookie_db = sqlite3.connect(self.cookie_database)
        mozilla_cursor = mozilla_cookie_db.cursor()
        try:
            mozilla_cursor.execute(str(sql_statement))
        except Exception as e:
            mozilla_cursor.close()
            os.remove(self.cookie_database)
            self._create_moz_cookies()
            mozilla_cookie_db = sqlite3.connect(self.cookie_database)
            mozilla_cursor = mozilla_cookie_db.cursor()
            mozilla_cursor.execute(str(sql_statement))

        return_objects = mozilla_cursor.fetchall()
        if(return_objects):
            return(return_objects)
        mozilla_cookie_db.commit()
        mozilla_cookie_db.close()

    # Mozilla Cookie entry format
    #
    # ('14', 'scorecardresearch.com', 'UID', '2baec64d-23.63.99.90-1342553308', '.scorecardresearch.com', '/', '1404761306', '1342815702910000', '1342553306190000', '0', '0')
    # (id_number,baseDomain,name,value,host,path,expiry,lastAccessed,creationTime,isSecure,isHttpOnly)
    #


    def calculate_mozilla_creationTime(self):
        crude_index = "0123456789"
        creation_time = str(int(time.time()))
        for add in range(16 - (len(creation_time) + 3)):
            creation_time += crude_index[add]
        creation_time += "000"
        return(creation_time)



    def insert_Cookie_Values(self,baseDomain,name,value,host,path,isSecure,isHttpOnly):
        '''Stores cookies into the moz_cookies table
        e.g "foobar.com","UID","1235423HYFFDTWB=YTER",".foobar.com","/","0","0"
        '''
        sql_code_a = "select max(id) from moz_cookies"

        response = self.execute_query(sql_code_a)[0][0]
        if(response):
            id_number = str(int(response) + 1)                           # calculates the next id number
        else:
            id_number = str(1)

        creationTime = self.calculate_mozilla_creationTime()    # 1342948082 + 023 + 0000 = (length == 16)
        lastAccessed = creationTime

        expiry = str(int(time.time()) + 1065600)                # Example : (Sun Jul 22 09:08:42 2012) -> (Fri Aug 3 17:45:51 2012) 12 days

        sql_code_b = "insert into moz_cookies values ('%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s')"
        sql_code_b = sql_code_b % (id_number,baseDomain,name,value,host,path,expiry,lastAccessed,creationTime,isSecure,isHttpOnly)
        self.execute_query(sql_code_b)



    def kill_Process(self,process_name):
        pids = subprocess.getstatusoutput("pidof " + process_name)[1]
        for pid in pids.split():
            subprocess.getstatusoutput("kill " + pid)


    def get_Cookie_Path(self,cookie_name):
        '''Finds the cookie path from user's profile
           sets cookie_database variable to cookie path'''
        cookie_path = str()
        file_object = open(os.devnull,"w")
        userprofile = os.path.expanduser("~")
        for root,direc,files in os.walk(userprofile,True):
            if((cookie_name in files) and ("firefox" in root.lower())):
                cookie_path = root + os.sep + cookie_name
                self.cookie_database = cookie_path
                return(cookie_path)


# USAGE:

# cookie = Mozilla_Cookie_Core()
# cookie.get_Cookie_Path("cookies.sqlite")  | cookie.cookie_database = "D:\\cookies.sqlite"

# retrun_list = cookie.execute_query("select * from moz_cookies")
# for entries in retrun_list:
#    print(entries)






import core
from PyQt5.QtWidgets import *
from gui.database import *
from core.functions import *
from core.variables import *

#
#  Class for Database key entries
#
class database_dialog(QtWidgets.QDialog,database_ui):
    update_database_label_signal = QtCore.pyqtSignal()

    def __init__(self):
        QtWidgets.QDialog.__init__(self)
        self.setupUi(self)
        self.retranslateUi(self)
        self.setWindowModality(QtCore.Qt.ApplicationModal)

        self.display_keys()

        self.insert_button.clicked.connect(self.insert_row)
        self.delete_button.clicked.connect(self.delete_row)
        self.save_button.clicked.connect(self.save_changes)




    def display_keys(self):
        connection = sqlite3.connect('key-database/Database.db')
        query = connection.cursor()
        query.execute('''select * from keys''')
        items = query.fetchall()
        query.close()

        for iterate in range(len(items)):              # Update QTable with entries from Database and

            tuple_sequence = items[iterate]

            if len(tuple_sequence) == 4:                      # If we have access point mac-address absent
                access_point_var = tuple_sequence[0]
                mac_address_var = '\t'
                encryption_var = tuple_sequence[1].upper()
                key_var = tuple_sequence[2]
                channel_var = tuple_sequence[3]
            else:
                access_point_var = tuple_sequence[0]
                mac_address_var = tuple_sequence[1]
                encryption_var = tuple_sequence[2].upper()
                key_var = tuple_sequence[3]
                channel_var = tuple_sequence[4]

            self.key_table.insertRow(iterate)

            access_point_display = QtWidgets.QTableWidgetItem()
            mac_address_display = QtWidgets.QTableWidgetItem()
            encryption_display = QtWidgets.QTableWidgetItem()
            key_display = QtWidgets.QTableWidgetItem()
            channel_display = QtWidgets.QTableWidgetItem()

            access_point_display.setText(QtCore.QCoreApplication.translate("Dialog", "%s"%(access_point_var), None, 0))
            self.key_table.setItem(iterate,0,access_point_display)

            mac_address_display.setText(QtCore.QCoreApplication.translate("Dialog", "%s"%(mac_address_var), None, 0))
            self.key_table.setItem(iterate,1,mac_address_display)

            encryption_display.setText(QtCore.QCoreApplication.translate("Dialog", "%s"%(encryption_var), None, 0))
            self.key_table.setItem(iterate,2,encryption_display)

            key_display.setText(QtCore.QCoreApplication.translate("Dialog", "%s"%(key_var), None, 0))
            self.key_table.setItem(iterate,3,key_display)

            channel_display.setText(QtCore.QCoreApplication.translate("Dialog", "%s"%(channel_var), None, 0))
            self.key_table.setItem(iterate,4,channel_display)



    def insert_row(self):
        self.key_table.insertRow(0)

    def delete_row(self):
        current_row = int(self.key_table.currentRow())
        self.key_table.removeRow(current_row)

    def save_changes(self):
        row_number = self.key_table.rowCount()
        fern_database_query('''delete from keys''')    # Truncate the "keys" table

        for controller in range(row_number):
            try:
                access_point1 = QtWidgets.QTableWidgetItem(self.key_table.item(controller,0))   # Get Cell content
                mac_address1 = QtWidgets.QTableWidgetItem(self.key_table.item(controller,1))
                encryption1 = QtWidgets.QTableWidgetItem(self.key_table.item(controller,2))
                key1 = QtWidgets.QTableWidgetItem(self.key_table.item(controller,3))
                channel1 = QtWidgets.QTableWidgetItem(self.key_table.item(controller,4))

                access_point = str(access_point1.text())                                    # Get cell content text
                mac_address = str(mac_address1.text())
                encryption2 = str(encryption1.text())
                encryption = encryption2.upper()
                key = key1.text()
                channel = channel1.text()

                if not (bool(access_point) and bool(mac_address) and bool(encryption) and bool(key) and bool(channel)):
                    raise(TypeError)

                set_key_entries(access_point,mac_address,encryption,key,channel)       # Write enrties to database

            except(TypeError):
                QtWidgets.QMessageBox.warning(self,"Empty Database Entries",\
                    "There are some fields with whitespaces,Please enter empty spaces with Access Point related data")
                break

        self.update_database_label_signal.emit()





import os
from gui.main_window import font_size
from PyQt5 import QtCore, QtWidgets, QtGui

font_setting = font_size()


try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s


class Ui_cookie_hijacker(object):
    def setupUi(self, cookie_hijacker):
        cookie_hijacker.setObjectName(_fromUtf8("cookie_hijacker"))
        cookie_hijacker.resize(857, 655)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(cookie_hijacker)
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.label_9 = QtWidgets.QLabel(cookie_hijacker)
        self.label_9.setText(_fromUtf8(""))
        self.label_9.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/cookies-icon.png"%(os.getcwd()))))
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.horizontalLayout_3.addWidget(self.label_9)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_2 = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_2.setFont(font)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout.addWidget(self.label_2)
        self.label_5 = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_5.setFont(font)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout.addWidget(self.label_5)
        self.verticalLayout_7.addLayout(self.verticalLayout)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_7.addItem(spacerItem)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName(_fromUtf8("horizontalLayout_14"))
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem1)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.combo_interface = QtWidgets.QComboBox(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.combo_interface.sizePolicy().hasHeightForWidth())
        self.combo_interface.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.combo_interface.setFont(font)
        self.combo_interface.setObjectName(_fromUtf8("combo_interface"))
        self.verticalLayout_6.addWidget(self.combo_interface)
        spacerItem2 = QtWidgets.QSpacerItem(177, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_6.addItem(spacerItem2)
        self.horizontalLayout_14.addLayout(self.verticalLayout_6)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.refresh_button = QtWidgets.QPushButton(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refresh_button.sizePolicy().hasHeightForWidth())
        self.refresh_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.refresh_button.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/PNG-Refresh.png-256x256.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refresh_button.setIcon(icon)
        self.refresh_button.setIconSize(QtCore.QSize(22, 23))
        self.refresh_button.setObjectName(_fromUtf8("refresh_button"))
        self.verticalLayout_5.addWidget(self.refresh_button)
        spacerItem3 = QtWidgets.QSpacerItem(82, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_5.addItem(spacerItem3)
        self.horizontalLayout_14.addLayout(self.verticalLayout_5)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem4)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem5)
        self.horizontalLayout_2.addLayout(self.horizontalLayout_14)
        self.verticalLayout_7.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3.addLayout(self.verticalLayout_7)
        self.verticalLayout_8.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName(_fromUtf8("horizontalLayout_12"))
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem6)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName(_fromUtf8("horizontalLayout_11"))
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.monitor_interface_led = QtWidgets.QLabel(cookie_hijacker)
        self.monitor_interface_led.setText(_fromUtf8(""))
        self.monitor_interface_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.monitor_interface_led.setObjectName(_fromUtf8("monitor_interface_led"))
        self.horizontalLayout_4.addWidget(self.monitor_interface_led)
        self.monitor_interface_label = QtWidgets.QLabel(cookie_hijacker)
        self.monitor_interface_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.monitor_interface_label.setFont(font)
        self.monitor_interface_label.setObjectName(_fromUtf8("monitor_interface_label"))
        self.horizontalLayout_4.addWidget(self.monitor_interface_label)
        self.horizontalLayout_10.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_11.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem7)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.sniffing_status_led = QtWidgets.QLabel(cookie_hijacker)
        self.sniffing_status_led.setText(_fromUtf8(""))
        self.sniffing_status_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.sniffing_status_led.setObjectName(_fromUtf8("sniffing_status_led"))
        self.horizontalLayout_6.addWidget(self.sniffing_status_led)
        self.sniffing_status_label = QtWidgets.QLabel(cookie_hijacker)
        self.sniffing_status_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.sniffing_status_label.setFont(font)
        self.sniffing_status_label.setObjectName(_fromUtf8("sniffing_status_label"))
        self.horizontalLayout_6.addWidget(self.sniffing_status_label)
        self.horizontalLayout_8.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_8)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem8)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.cookie_detection_led = QtWidgets.QLabel(cookie_hijacker)
        self.cookie_detection_led.setText(_fromUtf8(""))
        self.cookie_detection_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.cookie_detection_led.setObjectName(_fromUtf8("cookie_detection_led"))
        self.horizontalLayout_5.addWidget(self.cookie_detection_led)
        self.cookie_detection_label = QtWidgets.QLabel(cookie_hijacker)
        self.cookie_detection_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cookie_detection_label.setFont(font)
        self.cookie_detection_label.setObjectName(_fromUtf8("cookie_detection_label"))
        self.horizontalLayout_5.addWidget(self.cookie_detection_label)
        self.horizontalLayout.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_9.addLayout(self.horizontalLayout)
        self.horizontalLayout_11.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_12.addLayout(self.horizontalLayout_11)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem9)
        self.verticalLayout_8.addLayout(self.horizontalLayout_12)
        self.mitm_activated_label = QtWidgets.QLabel(cookie_hijacker)
        self.mitm_activated_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.mitm_activated_label.setFont(font)
        self.mitm_activated_label.setObjectName(_fromUtf8("mitm_activated_label"))
        self.verticalLayout_8.addWidget(self.mitm_activated_label)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName(_fromUtf8("horizontalLayout_17"))
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem10)
        self.ethernet_mode_radio = QtWidgets.QRadioButton(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.ethernet_mode_radio.setFont(font)
        self.ethernet_mode_radio.setChecked(True)
        self.ethernet_mode_radio.setObjectName(_fromUtf8("ethernet_mode_radio"))
        self.horizontalLayout_17.addWidget(self.ethernet_mode_radio)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem11)
        self.passive_mode_radio = QtWidgets.QRadioButton(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.passive_mode_radio.setFont(font)
        self.passive_mode_radio.setObjectName(_fromUtf8("passive_mode_radio"))
        self.horizontalLayout_17.addWidget(self.passive_mode_radio)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem12)
        self.verticalLayout_8.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName(_fromUtf8("horizontalLayout_16"))
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.groupBox_2 = QtWidgets.QGroupBox(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setTitle(_fromUtf8(""))
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.label = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label.setFont(font)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout_7.addWidget(self.label)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName(_fromUtf8("horizontalLayout_15"))
        self.wep_key_edit = QtWidgets.QLineEdit(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.wep_key_edit.setFont(font)
        self.wep_key_edit.setObjectName(_fromUtf8("wep_key_edit"))
        self.horizontalLayout_15.addWidget(self.wep_key_edit)
        self.channel_label = QtWidgets.QLabel(self.groupBox_2)
        self.channel_label.setObjectName(_fromUtf8("channel_label"))
        self.horizontalLayout_15.addWidget(self.channel_label)
        self.channel_combo = QtWidgets.QComboBox(self.groupBox_2)
        self.channel_combo.setObjectName(_fromUtf8("channel_combo"))
        self.horizontalLayout_15.addWidget(self.channel_combo)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_15)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        spacerItem13 = QtWidgets.QSpacerItem(20, 6, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_2.addItem(spacerItem13)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.horizontalLayout_16.addLayout(self.verticalLayout_4)
        self.verticalLayout_8.addLayout(self.horizontalLayout_16)
        self.treeWidget = QtWidgets.QTreeWidget(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.treeWidget.sizePolicy().hasHeightForWidth())
        self.treeWidget.setSizePolicy(sizePolicy)
        self.treeWidget.setObjectName(_fromUtf8("treeWidget"))
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        item_0.setFont(0, font)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/green_led.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        item_0.setFont(0, font)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        self.verticalLayout_8.addWidget(self.treeWidget)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.cookies_captured_label = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cookies_captured_label.setFont(font)
        self.cookies_captured_label.setObjectName(_fromUtf8("cookies_captured_label"))
        self.verticalLayout_3.addWidget(self.cookies_captured_label)
        spacerItem14 = QtWidgets.QSpacerItem(20, 17, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_3.addItem(spacerItem14)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName(_fromUtf8("horizontalLayout_13"))
        spacerItem15 = QtWidgets.QSpacerItem(1, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem15)
        self.start_sniffing_button = QtWidgets.QPushButton(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.start_sniffing_button.sizePolicy().hasHeightForWidth())
        self.start_sniffing_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.start_sniffing_button.setFont(font)
        self.start_sniffing_button.setObjectName(_fromUtf8("start_sniffing_button"))
        self.horizontalLayout_13.addWidget(self.start_sniffing_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_13)
        spacerItem16 = QtWidgets.QSpacerItem(20, 17, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_3.addItem(spacerItem16)
        self.verticalLayout_8.addLayout(self.verticalLayout_3)

        self.retranslateUi(cookie_hijacker)
        QtCore.QMetaObject.connectSlotsByName(cookie_hijacker)

    def retranslateUi(self, cookie_hijacker):
        cookie_hijacker.setWindowTitle(QtWidgets.QApplication.translate("cookie_hijacker", "Fern - Cookie Hijacker", None, 0))
        self.label_2.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Fern Cookie Hijacker is an Ethernet and WIFI based session Hijacking tool able to clone remote online web sessions by sniffing and capturing session cookie", None, 0))
        self.label_5.setText(QtWidgets.QApplication.translate("cookie_hijacker", "packets from remote hosts by leveraging various internal MITM attacks with routing capabilities", None, 0))
        self.refresh_button.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Refresh", None, 0))
        self.monitor_interface_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Ethernet Mode", None, 0))
        self.sniffing_status_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Sniffing Status", None, 0))
        self.cookie_detection_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Cookie Detection Buffer", None, 0))
        self.mitm_activated_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Internal MITM Engine Activated", None, 0))
        self.ethernet_mode_radio.setToolTip(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Use this option if you are currently connected to the ethernet gateway/access point</p></body></html>", None, 0))
        self.ethernet_mode_radio.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Ethernet Mode", None, 0))
        self.passive_mode_radio.setToolTip(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Use this option if you are not connected to access point</p></body></html>", None, 0))
        self.passive_mode_radio.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Passive Mode", None, 0))
        self.label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Gateway IP Address / Router IP Address:", None, 0))
        self.channel_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Channel:", None, 0))
        self.treeWidget.headerItem().setText(0, QtWidgets.QApplication.translate("cookie_hijacker", " ", None, 0))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.topLevelItem(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "192.168.0.1", None, 0))
        self.treeWidget.topLevelItem(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.google.com", None, 0))
        self.treeWidget.topLevelItem(0).child(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "HTTP response", None, 0))
        self.treeWidget.topLevelItem(0).child(1).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.twitter.com", None, 0))
        self.treeWidget.topLevelItem(0).child(1).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "HTTP over", None, 0))
        self.treeWidget.topLevelItem(1).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "198.178.23.1", None, 0))
        self.treeWidget.topLevelItem(1).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.gmail.com", None, 0))
        self.treeWidget.topLevelItem(1).child(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "respose server", None, 0))
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.cookies_captured_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; color:#008000;\">5 Cookies Captured</span></p></body></html>", None, 0))
        self.start_sniffing_button.setText(QtWidgets.QApplication.translate("cookie_hijacker", "   Start Sniffing   ", None, 0))




import os
import re
import sys
import time
import csv
import threading
import shutil
import sqlite3
import subprocess
from urllib import request

from core import variables
from PyQt5 import QtCore, QtGui, QtWidgets

from core.wep import *
from core.wpa import *
from core.wps import *
from core.tools import *
from core.database import *
from core.functions import *
from core.settings import *

from gui.main_window import *

__version__ = 3.14


#
# Main Window Class
#
class mainwindow(QtWidgets.QDialog, Ui_Dialog):
    file_downloaded_signal = QtCore.pyqtSignal()
    finished_downloading_signal = QtCore.pyqtSignal()
    internal_scan_error_signal = QtCore.pyqtSignal()
    restart_application_signal = QtCore.pyqtSignal()
    download_failed_signal = QtCore.pyqtSignal()
    current_version_signal = QtCore.pyqtSignal()
    new_update_available_signal = QtCore.pyqtSignal()
    already_latest_update_signal = QtCore.pyqtSignal()
    previous_message_signal = QtCore.pyqtSignal()
    failed_update_signal = QtCore.pyqtSignal()
    interface_cards_not_found_signal = QtCore.pyqtSignal()
    interface_cards_found_signal = QtCore.pyqtSignal()
    monitor_mode_enabled_signal = QtCore.pyqtSignal()
    monitor_failed_signal = QtCore.pyqtSignal()
    wep_number_changed_signal = QtCore.pyqtSignal()
    wep_button_true_signal = QtCore.pyqtSignal()
    wep_button_false_signal = QtCore.pyqtSignal()
    wpa_button_false_signal = QtCore.pyqtSignal()
    wpa_button_true_signal = QtCore.pyqtSignal()
    wpa_number_changed_signal = QtCore.pyqtSignal()

    def __init__(self):
        QtWidgets.QDialog.__init__(self)
        self.setupUi(self)
        self.retranslateUi(self)
        self.refresh_interface()
        self.evaliate_permissions()

        self.monitor_interface = str()
        self.wep_count = str()
        self.wpa_count = str()
        self.scan_control = 1

        self.scanner = QtCore.QProcess()

        self.interface_cards = list()

        variables.wps_functions = WPS_Attack()  # WPS functions

        self.movie = QtGui.QMovie(self)
        self.animate_monitor_mode(True)  # Loading gif animation

        self.settings = Fern_settings()

        self.timer = QtCore.QTimer()
        self.timer.timeout.connect(self.display_timed_objects)
        self.timer.setInterval(3000)



        # self.DoubleClicked.connect(self.mouseDoubleClickEvent)
        self.refresh_intfacebutton.clicked.connect(self.refresh_interface)
        self.interface_combo.currentIndexChanged['QString'].connect(self.setmonitor)
        self.monitor_mode_enabled_signal.connect(self.monitor_mode_enabled)
        self.monitor_failed_signal.connect(self.display_error_monitor)
        self.interface_cards_found_signal.connect(self.interface_cards_found)
        self.interface_cards_not_found_signal.connect(self.interface_card_not_found)
        self.scan_button.clicked.connect(self.scan_network)
        self.wep_button.clicked.connect(self.wep_attack_window)
        self.wpa_button.clicked.connect(self.wpa_attack_window)
        self.tool_button.clicked.connect(self.tool_box_window)

        self.wep_number_changed_signal.connect(self.wep_number_changed)
        self.wep_button_true_signal.connect(self.wep_button_true)
        self.wep_button_false_signal.connect(self.wep_button_false)

        self.wpa_number_changed_signal.connect(self.wpa_number_changed)
        self.wpa_button_true_signal.connect(self.wpa_button_true)
        self.wpa_button_false_signal.connect(self.wpa_button_false)

        self.database_button.clicked.connect(self.database_window)
#        self.update_button.clicked.connect(self.update_fern)
        self.finished_downloading_signal.connect(self.finished_downloading_files)
        self.restart_application_signal.connect(self.restart_application)
#        self.failed_update_signal.connect(self.update_fail)
        self.already_latest_update_signal.connect(self.latest_update)
        self.previous_message_signal.connect(self.latest_svn)
        self.new_update_available_signal.connect(self.new_update_avialable)
        self.current_version_signal.connect(self.current_update)
        self.download_failed_signal.connect(self.download_failed)
        self.internal_scan_error_signal.connect(self.scan_error_display)
        self.file_downloaded_signal.connect(self.downloading_update_files)

        self.update_label.setText(
            '<font color=green>Currently installed version: Revision %s</font>' % (self.installed_revision()))

        # Display update status on main_windows
        t = threading.Thread(target=self.update_initializtion_check)
        t.start()

        self.set_WindowFlags()

        self.update_database_label()
        self.set_xterm_settings()

    def set_WindowFlags(self):
        try:
            self.setWindowFlags(
                QtCore.Qt.WindowCloseButtonHint | QtCore.Qt.WindowMaximizeButtonHint)  # Some older versions of Qt4 dont support some flags
        except:
            pass

    def display_timed_objects(self):
        self.show_Fern_Pro_tip()
        self.timer.stop()

    def show_Fern_Pro_tip(self):
        if (self.settings.setting_exists("fern_pro_tips")):
            if (self.settings.read_last_settings("fern_pro_tips") == "0"):
                tips = Fern_Pro_Tips()
                tips.exec_()
        else:
            self.settings.create_settings("fern_pro_tips", "0")
            tips = Fern_Pro_Tips()
            tips.exec_()

    #
    #   Read database entries and count entries then set Label on main window
    #
    def update_database_label(self):
        connection = sqlite3.connect(os.getcwd() + '/key-database/Database.db')
        query = connection.cursor()
        query.execute('''select * from keys''')
        items = query.fetchall()
        connection.close()
        if len(items) == 0:
            self.label_16.setText('<font color=red>No Key Entries</font>')
        else:
            self.label_16.setText('<font color=green>%s Key Entries</font>' % (str(len(items))))

    #
    #   Read last xterm settings
    #
    def set_xterm_settings(self):
        if not self.settings.setting_exists("xterm"):
            self.settings.create_settings("xterm", str())
        variables.xterm_setting = self.settings.read_last_settings("xterm")

    #
    # SIGNALs for update threads
    #
    def update_fail(self):
        self.update_label.setText('<font color=red>Unable to check for updates,network timeout')

    def download_failed(self):
        self.update_label.setText('<font color=red>Download failed,network timeout')

    def downloading_update_files(self):
        global file_total
        global files_downloaded

        self.update_label.setText('<font color=green>Downloading.. %s Complete</font>' \
                                  % (self.percentage(files_downloaded, file_total)))

    def installed_revision(self):
        svn_info = subprocess.getstatusoutput('svn info ' + directory)
        if svn_info[0] == 0:
            svn_version = svn_info[1].splitlines()[4].strip('Revision: ')
        else:
            svn_version = '94'
        return svn_version

    def finished_downloading_files(self):
        self.update_label.setText('<font color=green>Finished Downloading</font>')

    def restart_application(self):
        self.update_label.setText('<font color=red>Please Restart application</font>')

    def latest_update(self):
        self.update_label.setText('<font color=green>No new update is available for download</font>')

    def current_update(self):
        self.update_label.setText(
            '<font color=green>Currently installed version: Revision %s</font>' % (self.installed_revision()))

    def latest_svn(self):
        self.update_label.setText('<font color=green>Latest update is already installed</font>')

    def new_update_avialable(self):
        self.update_label.setText('<font color=green>No New Update is Available</font>')
#        self.update_button.setFocus()

    def update_error(self):
        global svn_access
        global svn_failure_message
        svn_failure_message = str()
        svn_failure = svn_access.stderr
        svn_failure_message = svn_failure.read()

    #
    # Update Fern application via SVN,updates at ("svn checkout http://github.com/savio-code/fern-wifi-cracker/trunk/Fern-Wifi-Cracker/")
    #
    def update_fern(self):
        global updater_control
        updater_control = 1
        self.update_label.setText('<font color=green>Checking for update...</font>')
        t = threading.Thread(target=self.update_launcher)
        t.start()

    def percentage(self, current, total):
        float_point = float(current) / float(total)
        calculation = int(float_point * 100)
        percent = str(calculation) + '%'
        return (percent)

    def update_launcher(self):
        ''' Downloads and installs update files
        '''
        global svn_access
        global file_total
        global files_downloaded
        global fern_directory

        file_total = int()
        files_downloaded = int()

        fern_directory = os.getcwd()

        update_directory = '/tmp/Fern-Wifi-Cracker/'

        try:
            online_response_check = request.urlopen(
                'https://raw.githubusercontent.com/savio-code/fern-wifi-cracker/master/Fern-Wifi-Cracker/version')
            online_response = online_response_check.read().decode("ascii",errors="ignore")

            online_files = re.compile(r'total_files = \d+', re.IGNORECASE)

            for online_file_total in online_response.splitlines():
                if re.match(online_files, online_file_total):
                    file_total = int(online_file_total.split()[2])

            if 'Fern-Wifi-Cracker' in os.listdir('/tmp/'):
                variables.exec_command('rm -r /tmp/Fern-Wifi-Cracker')

            svn_access = subprocess.Popen(
                'cd /tmp/ \n svn checkout https://github.com/savio-code/fern-wifi-cracker/trunk/Fern-Wifi-Cracker/', \
                shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, stdin=subprocess.PIPE)
            svn_update = svn_access.stdout
            t = threading.Thread(target=self.update_error)
            t.start()

            while True:
                response = svn_update.readline()
                if len(response) > 0:
                    files_downloaded += 1
                    self.file_downloaded_signal.emit()

                if str('revision') in str(response):
                    self.finished_downloading_signal.emit()
                    # Delete all old files (*.py,*.py etc) except ".font_setting.dat" file
                    for old_file in os.listdir(os.getcwd()):
                        if os.path.isfile(os.getcwd() + os.sep + old_file) and old_file != '.font_settings.dat':
                            os.remove(os.getcwd() + os.sep + old_file)
                            # Delete all old directories except the "key-database" directory
                    for old_directory in os.listdir(os.getcwd()):
                        if os.path.isdir(os.getcwd() + os.sep + old_directory) and old_directory != 'key-database':
                            shutil.rmtree(os.getcwd() + os.sep + old_directory)

                    for update_file in os.listdir(
                            '/tmp/Fern-Wifi-Cracker'):  # Copy New update files to working directory
                        if os.path.isfile(update_directory + update_file):
                            shutil.copyfile(update_directory + update_file, os.getcwd() + os.sep + update_file)
                        else:
                            shutil.copytree(update_directory + update_file, os.getcwd() + os.sep + update_file)

                    for new_file in os.listdir(os.getcwd()):  # chmod New files to allow permissions
                        os.chmod(os.getcwd() + os.sep + new_file,0o777)

                    time.sleep(5)
                    self.restart_application_signal.emit()
                    break
                if len(svn_failure_message) > 2:
                    self.download_failed_signal.emit()
                    break

        except(request.URLError, request.HTTPError):
            self.download_failed_signal.emit()

    #
    # Update checker Thread
    #
    def update_initializtion_check(self):
        global updater_control
        updater_control = 0
        while updater_control != 1:
            try:
                online_response_thread = request.urlopen(
                    'https://raw.githubusercontent.com/savio-code/fern-wifi-cracker/master/Fern-Wifi-Cracker/version')
                online_response_string = ''
                online_response = online_response_thread.read().decode("ascii",errors="ignore")

                online_version = re.compile(r'version = \d+\.?\d+', re.IGNORECASE)

                for version_iterate in online_response.splitlines():
                    if re.match(online_version, version_iterate):
                        online_response_string += version_iterate

                update_version_number = float(online_response_string.split()[2])

                if float(__version__) != update_version_number:
                    self.new_update_available_signal.emit()
                    break

                if float(__version__) == update_version_number:
                    self.already_latest_update_signal.emit()
                    time.sleep(20)
                    self.previous_message_signal.emit()
                    break

            except Exception:
                self.failed_update_signal.emit()
                time.sleep(9)

    #
    # Launches Tool Box window
    #
    def tool_box_window(self):
        tool_box = tool_box_window()
        tool_box.exec_()

    #
    # Execute the wep attack window
    #
    def wep_attack_window(self):
        if 'WEP-DUMP' not in os.listdir('/tmp/fern-log'):
            os.mkdir('/tmp/fern-log/WEP-DUMP', 448)         # 488 =  Octal 700
        else:
            variables.exec_command('rm -r /tmp/fern-log/WEP-DUMP/*')
        wep_run = wep_attack_dialog()

        wep_run.update_database_label_signal.connect(self.update_database_label)
        wep_run.stop_scan_signal.connect(self.stop_network_scan)

        wep_run.exec_()

    #
    # Execute the wep attack window
    #
    def wpa_attack_window(self):
        variables.exec_command('killall aircrack-ng')
        if 'WPA-DUMP' not in os.listdir('/tmp/fern-log'):
            os.mkdir('/tmp/fern-log/WPA-DUMP', 448)
        else:
            variables.exec_command('rm -r /tmp/fern-log/WPA-DUMP/*')
        wpa_run = wpa_attack_dialog()

        wpa_run.update_database_label_signal.connect(self.update_database_label)
        wpa_run.stop_scan_signal.connect(self.stop_network_scan)

        wpa_run.exec_()

    #
    # Execute database Window
    #
    def database_window(self):
        database_run = database_dialog()
        database_run.update_database_label_signal.connect(self.update_database_label)
        database_run.exec_()




    #
    # Refresh wireless network interface card and update combobo
    #

    def refresh_interface(self):
        variables.exec_command('killall airodump-ng')
        variables.exec_command('killall airmon-ng')

        self.animate_monitor_mode(True)
        self.mon_label.clear()
        self.interface_combo.clear()
        self.interface_combo.setEnabled(True)
        self.interface_cards = list()

        t = threading.Thread(target=self.refresh_card_thread)
        t.start()

    def refresh_card_thread(self):
        # Disable cards already on monitor modes
        wireless_interfaces = str(subprocess.getstatusoutput('airmon-ng'))
        prev_monitor = os.listdir('/sys/class/net')
        monitor_interfaces_list = []
        for monitors in prev_monitor:
            if monitors in wireless_interfaces:
                monitor_interfaces_list.append(monitors)
        for monitored_interfaces in monitor_interfaces_list:
            variables.exec_command('airmon-ng stop %s' % (monitored_interfaces))

        # List Interface cards
        compatible_interface = str(subprocess.getoutput("airmon-ng"))
        interface_list = os.listdir('/sys/class/net')

        # Interate over interface output and update combo box
        isHasCompatibleCard = False
        for interface in interface_list:
            if interface.lower() in compatible_interface.lower():
                isHasCompatibleCard = True
                break

        if not isHasCompatibleCard:
            self.interface_cards_not_found_signal.emit()
        else:
            for interface in interface_list:
                if interface in compatible_interface:
                    if not interface.startswith('mon'):
                        self.interface_cards.append(interface)
            self.interface_cards_found_signal.emit()


    def interface_card_not_found(self):
        self.interface_combo.setEnabled(False)
        self.mon_label.setText("<font color=red>No Wireless Interface was found</font>")
        self.animate_monitor_mode(False)

    def interface_cards_found(self):
        self.interface_combo.addItem('Select Interface')
        interface_icon = QtGui.QIcon("%s/resources/mac_address.png" % (os.getcwd()))
        for interface in self.interface_cards:
            self.interface_combo.addItem(interface_icon, interface)
        self.mon_label.setText("<font color=red>Select an interface card</font>")
        self.animate_monitor_mode(False)

    #
    # Animates monitor mode by loading gif
    #
    def animate_monitor_mode(self, status):
        self.movie = QtGui.QMovie("%s/resources/loading.gif" % (os.getcwd()))
        self.movie.start()
        self.loading_label.setMovie(self.movie)

        if (status):  # if status == True (setting of monitor mode is in progress)
            self.interface_combo.setEnabled(False)
            self.loading_label.setVisible(True)
            self.mon_label.setVisible(False)
        else:
            self.interface_combo.setEnabled(True)
            self.loading_label.setVisible(False)
            self.mon_label.setVisible(True)

    #
    # Set monitor mode on selected monitor from combo list
    #
    def setmonitor(self):
        last_settings = str()
        self.monitor_interface = str()
        monitor_card = str(self.interface_combo.currentText())
        if monitor_card != 'Select Interface':
            mac_settings = self.settings.setting_exists('mac_address')
            if mac_settings:
                last_settings = self.settings.read_last_settings('mac_address')
            threading.Thread(target=self.set_monitor_thread, args=(monitor_card, mac_settings, last_settings,)).start()
            self.animate_monitor_mode(True)
        else:
            self.mon_label.setText("<font color=red>Monitor Mode not enabled check manually</font>")
            self.animate_monitor_mode(False)

    def killConflictProcesses(self):
        process = subprocess.getstatusoutput("airmon-ng check")
        status = process[0]
        output = process[1]

        if (status == 0):
            for line in output.splitlines():
                splitedLines = line.split()
                if (len(splitedLines) >= 2):
                    prefix = str(splitedLines[0])
                    if (prefix.isdigit()):
                        pid = int(prefix)
                        killProcess(pid)

    def set_monitor_thread(self, monitor_card, mac_setting_exists, last_settings):
        self.killConflictProcesses()

        subprocess.getstatusoutput('ifconfig %s down' % (
            self.monitor_interface))  # Avoid this:  "ioctl(SIOCSIWMODE) failed: Device or resource busy"

        status = str(subprocess.getoutput("airmon-ng start %s" % (monitor_card)))
        messages = ("monitor mode enabled", "monitor mode vif enabled", "monitor mode already")

        monitor_created = False;

        for x in messages:
            if (x in status.lower()):
                monitor_created = True

        if (monitor_created):
            monitor_interface_process = str(subprocess.getoutput("airmon-ng"))


            regex = re.compile(r"\bmon\d+\b", re.IGNORECASE)
            interfaces = regex.findall(monitor_interface_process)

            if len(interfaces) == 0:
                regex = re.compile(r"\bwl[a-z0-9]+mon\b", re.IGNORECASE)
                interfaces = regex.findall(monitor_interface_process)

                if len(interfaces) == 0:
                    self.monitor_failed_signal.emit()
                    return

            if (interfaces):
                self.monitor_interface = interfaces[0]
            else:
                self.monitor_interface = monitor_card

            variables.monitor_interface = self.monitor_interface
            self.interface_combo.setEnabled(False)
            variables.wps_functions.monitor_interface = self.monitor_interface
            self.monitor_mode_enabled_signal.emit()

            # Create Fake Mac Address and index for use
            mon_down = subprocess.getstatusoutput('ifconfig %s down' % (self.monitor_interface))
            if mac_setting_exists:
                variables.exec_command('macchanger -m %s %s' % (last_settings, self.monitor_interface))
            else:
                variables.exec_command('macchanger -A %s' % (self.monitor_interface))
            # mon_up = subprocess.getstatusoutput('ifconfig %s up'%(self.monitor_interface))       # Lets leave interface down to avoid channel looping during channel specific attack

            subprocess.getstatusoutput('ifconfig %s down' % (self.monitor_interface))

            for iterate in os.listdir('/sys/class/net'):
                if str(iterate) == str(self.monitor_interface):
                    os.chmod('/sys/class/net/' + self.monitor_interface + '/address', 0o777)
                    variables.monitor_mac_address = reader(
                        '/sys/class/net/' + self.monitor_interface + '/address').strip()
                    variables.wps_functions.monitor_mac_address = variables.monitor_mac_address
        else:
            self.monitor_failed_signal.emit()

    def display_monitor_error(self, color, error):
        message = "<font color='" + color + "'>" + error + "</font>"
        self.mon_label.setText(message)
        self.animate_monitor_mode(False)

    def tip_display(self):
        tips = tips_window()
        tips.type = 1
        tips.exec_()

    def display_error_monitor(self):
        self.display_monitor_error("red", "problem occured while setting up the monitor mode of selected")

    def monitor_mode_enabled(self):
        self.mon_label.setText("<font color=green>Monitor Mode Enabled on %s</font>" % (self.monitor_interface))
        self.animate_monitor_mode(False)
        # Execute tips
        if (self.settings.setting_exists("tips")):
            if (self.settings.read_last_settings("tips") == "0"):
                self.tip_display()
        else:
            self.settings.create_settings("tips", "1")
            self.tip_display()

    #
    # Double click event for poping of settings dialog box
    #
    def mouseDoubleClickEvent(self, event):
        if (len(self.monitor_interface)):
            setting = settings_dialog()
            setting.exec_()
        else:
            self.mon_label.setText("<font color=red>Enable monitor mode to access settings</font>")

    def scan_error_display(self):
        global error_catch
        self.stop_scan_network()
        QtWidgets.QMessageBox.warning(self, 'Scan Error',
                                      'Fern failed to start scan due to an airodump-ng error: <font color=red>' \
                                      + error_catch[1] + '</font>')

    #
    # Scan for available networks
    #
    def scan_network(self):
        self.scan_control = 0

        self.wep_count = int()
        self.wpa_count = int()

        variables.wep_details = {}
        variables.wpa_details = {}

        variables.wps_functions = WPS_Attack()  # WPS functions

        variables.wps_functions.monitor_interface = self.monitor_interface
        variables.wps_functions.monitor_mac_address = variables.monitor_mac_address

        variables.wps_functions.start_WPS_Devices_Scan()  # Starts WPS Scanning

        if not self.monitor_interface:
            self.mon_label.setText("<font color=red>Enable monitor mode before scanning</font>")
        else:
            self.wpa_button.setEnabled(False)
            self.wep_button.setEnabled(False)
            self.wep_clientlabel.setEnabled(False)
            self.wpa_clientlabel.setEnabled(False)
            self.wep_clientlabel.setText("None Detected")
            self.wpa_clientlabel.setText("None Detected")
            self.label_7.setText("<font Color=green>\t Initializing</font>")

            self.scan_networks()

            self.scan_button.clicked.disconnect(self.scan_network)
            self.scan_button.clicked.connect(self.stop_scan_network)


    def stop_scan_network(self):
        global error_catch
        self.scan_control = 1
        variables.exec_command('rm -r /tmp/fern-log/*.cap')
        variables.exec_command('killall airodump-ng')
        variables.exec_command('killall airmon-ng')
        self.label_7.setText("<font Color=red>\t Stopped</font>")
        variables.wps_functions.stop_WPS_Scanning()  # Stops WPS scanning
        self.wep_clientlabel.setText("None Detected")
        self.wpa_clientlabel.setText("None Detected")
        self.scan_button.clicked.disconnect(self.stop_scan_network)
        self.scan_button.clicked.connect(self.scan_network)
        self.scanner.kill()

    def stop_network_scan(self):
        self.scan_control = 1
        variables.exec_command('killall airodump-ng')
        variables.exec_command('killall airmon-ng')
        self.scanner.kill();
        self.label_7.setText("<font Color=red>\t Stopped</font>")

    #
    # WEP Thread SLOTS AND SIGNALS
    #
    def wep_number_changed(self):
        self.wep_clientlabel.setText('<font color=red>%s</font><font color=red>\t Detected</font>' % (self.wep_count))

    def wep_button_true(self):
        self.wep_button.setEnabled(True)
        self.wep_clientlabel.setEnabled(True)

    def wep_button_false(self):
        self.wep_button.setEnabled(False)
        self.wep_clientlabel.setEnabled(False)
        self.wep_clientlabel.setText('None Detected')

    #
    # WPA Thread SLOTS AND SIGNALS
    #
    def wpa_number_changed(self):
        self.wpa_clientlabel.setText('<font color=red>%s</font><font color=red>\t Detected</font>' % (self.wpa_count))

    def wpa_button_true(self):
        self.wpa_button.setEnabled(True)
        self.wpa_clientlabel.setEnabled(True)

    def wpa_button_false(self):
        self.wpa_button.setEnabled(False)
        self.wpa_clientlabel.setEnabled(False)
        self.wpa_clientlabel.setText('None Detected')

    #
    # WEP SCAN THREADING FOR AUTOMATIC SCAN OF NETWORK
    #
    ###################

    def scan_all_channels(self):
        self.scanner.start("airodump-ng",["--write","/tmp/fern-log/zfern","--output-format","csv",self.monitor_interface])

    def scan_channel(self):
        self.scanner.start("airodump-ng",["--channel",variables.static_channel,"--write","/tmp/fern-log/zfern","--output-format","csv",self.monitor_interface])


    def check_csv_for_networks(self):
        time.sleep(5)
        self.wpa_count = 0
        self.wep_count = 0

        path = "/tmp/fern-log/zfern-01.csv"
        while self.scan_control != 1:
            if not os.path.exists(path):
                time.sleep(1)
                continue

            try:
                with open(path, newline='') as csvfile:
                    scanData = csv.reader(csvfile)

                    for row in scanData:
                        length = len(row)
                        if length > 0:
                            if (variables.is_mac_address(row[0])) and (length >= 13):
                                bssid = row[0].strip(" ")
                                channel = row[3].strip(" ")
                                power = row[8].strip(" ")
                                speed = row[4].strip(" ")
                                encryption = row[5].strip(" ")
                                essid = row[13]

                                if encryption.upper().startswith("WPA"):
                                    self.wpa_count += 1
                                    wpa_details[essid] = [bssid, channel, speed, power]

                                if encryption.upper().startswith("WEP"):
                                    self.wep_count += 1
                                    wep_details[essid] = [bssid, channel, speed, power]

                    if int(self.wep_count) > 0:
                        self.wep_number_changed_signal.emit()
                        self.wep_button_true_signal.emit()
                    else:
                        self.wep_button_false_signal.emit()

                    if int(self.wpa_count) > 0:
                        self.wpa_button_true_signal.emit()
                        self.wpa_number_changed_signal.emit()
                    else:
                        self.wpa_button_false_signal.emit()

            except Exception as e:
                print("Error occurred during scan: ", e)

            time.sleep(3)


    def scan_networks(self):
        global xterm_setting
        variables.exec_command("killall airodump-ng")
        variables.exec_command('rm -r /tmp/fern-log/*.csv')
        variables.exec_command('rm -r /tmp/fern-log/*.cap')
        variables.exec_command('rm -r /tmp/fern-log/WPA/*.csv')
        variables.exec_command('rm -r /tmp/fern-log/WPA/*.cap')


        # Channel desision block
        if self.scan_control == 0:
            if self.scanner.state() == QtCore.QProcess.Running:
                self.scanner.kill()
            if not variables.static_channel:
                self.scan_all_channels()
            else:
                self.scan_channel()

        if self.scan_control != 1:
            self.label_7.setText("<font Color=green>\t Active</font>")

        threading.Thread(target=self.check_csv_for_networks).start()


    def showEvent(self, event):
        self.timer.start()

    def evaliate_permissions(self):
        if os.geteuid() != 0:
            QtWidgets.QMessageBox.warning(self, "Insufficient Priviledge",
                                          "Aircrack and other dependencies need root priviledge to function, Please run application as root")
            sys.exit()




import re
import os
import string
import webbrowser
from PyQt5 import QtCore, QtGui, QtWidgets

from gui.ray_fusion import *
from core.variables import *
from core.toolbox.bruteforce_core import *


tutorial_link = "http://www.youtube.com/watch?v=_ztQQWMoVX4"    # Video Tutorial link


class Ray_Fusion(QtWidgets.QDialog,Ui_ray_fusion):
    def __init__(self):
        QtWidgets.QDialog.__init__(self)
        self.setupUi(self)
        self.retranslateUi(self)

        self.custom_user_wordlist = str()          # Path to the custom user wordlist
        self.custom_password_wordlist = str()      # Path to the custom password wordlist

        self.start_flag = True                      # If False then Stop

        self.table_index = 0
        self.bruteforce_core = Bruteforce_Attack()      # Bruteforce Attack Class

        self.http_https_pixmap = QtGui.QPixmap("%s/resources/Page-World.ico" % (os.getcwd()))
        self.telnet_pixmap = QtGui.QPixmap("%s/resources/Application-Osx-Terminal.ico" % (os.getcwd()))
        self.ftp_pixmap = QtGui.QPixmap("%s/resources/Ftp.ico" % (os.getcwd()))
        self.red_led = QtGui.QPixmap("%s/resources/red_led.png" % (os.getcwd()))
        self.green_led = QtGui.QPixmap("%s/resources/green_led.png" % (os.getcwd()))

        self.http_https_radio.clicked.connect(self.HTTP_HTTPS_Mode)
        self.telnet_radio.clicked.connect(self.TELNET_Mode)
        self.ftp_radio.clicked.connect(self.FTP_Mode)
        self.default_wordlist_radio.clicked.connect(self.select_Wordlist_type)
        self.custom_wordlist_radio.clicked.connect(self.select_Wordlist_type)
        self.settings_button.clicked.connect(self.show_hide_settings)
        self.help_button.clicked.connect(self.show_help)
        self.launch_bruteforce.clicked.connect(self.Start_Attack)

        self.save_credentials.clicked.connect(self.save_bruteforced_credentials)
        self.clear_credentials.clicked.connect(self.clear_bruteforced_credentials)

        self.userlist_button.clicked.connect(self.select_custom_user_wordlist)
        self.passwordlist_button.clicked.connect(self.select_custom_password_wordlist)

        self.bruteforce_core.Next_Try_signal.connect(self.display_progress)
        self.bruteforce_core.We_Got_Error_signal.connect(self.display_error_message)
        self.bruteforce_core.successful_login_signal['QString', 'QString'].connect(self.show_credentials)

        self.bruteforce_core.Finished_bruteforce_signal.connect(self.Stop_Notification)

        self.reset_objects()
        self.set_Window_Max()

        self.HTTP_HTTPS_Mode()
        self.custom_wordlist_groupbox.setVisible(False)




    def reset_objects(self):
        self.credential_table.clear()
        self.save_credentials.setEnabled(False)
        self.clear_credentials.setEnabled(False)
        self.statistics_username.setText("Username: ")
        self.statistics_password.setText("Password: ")
        self.statistics_percentage.setText("0% Complete")


    def set_Window_Max(self):
        try:
            self.setWindowFlags(
            QtCore.Qt.WindowMinMaxButtonsHint |
            QtCore.Qt.WindowCloseButtonHint |
            QtCore.Qt.Dialog)
        except:pass


    def show_help(self):
        QtWidgets.QMessageBox.about(self,"About Fern - Ray Fusion","Fern - Ray Fusion is a bruteforce attack tool used to audit the list of supported network services and returns login credentials of the target service when successful.")
        answer = QtWidgets.QMessageBox.question(self,"Tutorial","Would you like to view a video tutorial on how to use the tool?",QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
        if(answer == QtWidgets.QMessageBox.Yes):
            webbrowser.open_new_tab(tutorial_link)


    def HTTP_HTTPS_Mode(self):
        self.port_edit.setVisible(False)
        self.label.setPixmap(self.http_https_pixmap)
        self.target_edit.clear()
        self.target_edit.setFocus()

    def TELNET_Mode(self):
        self.port_edit.setVisible(True)
        self.port_edit.setText("23")
        self.label.setPixmap(self.telnet_pixmap)
        self.target_edit.clear()
        self.target_edit.setFocus()

    def FTP_Mode(self):
        self.port_edit.setVisible(True)
        self.port_edit.setText("21")
        self.label.setPixmap(self.ftp_pixmap)
        self.target_edit.clear()
        self.target_edit.setFocus()


    def select_Wordlist_type(self):
        if(self.default_wordlist_radio.isChecked()):
            self.custom_wordlist_groupbox.setVisible(False)
            return
        self.custom_wordlist_groupbox.setVisible(True)


    def show_hide_settings(self):
        if(self.settings_groupbox.isVisible()):
            self.settings_button.setText("Show Settings")
            self.settings_groupbox.setVisible(False)
            self.custom_wordlist_groupbox.setVisible(False)
            return
        self.settings_button.setText("Hide Settings")
        self.settings_groupbox.setVisible(True)
        self.select_Wordlist_type()


    def select_custom_user_wordlist(self):
        self.custom_user_wordlist = str()
        path = QtWidgets.QFileDialog.getOpenFileName(self,"Select User Wordlist",str())[0]
        if(path):
            self.custom_user_wordlist = path
            self.user_wordlist_led.setPixmap(self.green_led)
            return
        self.custom_user_wordlist = str()
        self.user_wordlist_led.setPixmap(self.red_led)


    def select_custom_password_wordlist(self):
        self.custom_password_wordlist = str()
        path = QtWidgets.QFileDialog.getOpenFileName(self,"Select Password Wordlist",str())[0]
        if(path):
            self.custom_password_wordlist = path
            self.password_wordlist_led.setPixmap(self.green_led)
            return
        self.custom_password_wordlist= str()
        self.password_wordlist_led.setPixmap(self.red_led)


    def display_progress(self):
        statistics = self.bruteforce_core.next_try_details                      # [23%,"username","password"]
        self.statistics_percentage.setText("<font color=green><b>" + statistics[0] + " Complete</b></font>")
        if(len(statistics[1]) > 7):
            self.statistics_username.setText("Username: <font color=green>" + statistics[1][0:7] + "...</font>")
        else:
            self.statistics_username.setText("Username: <font color=green>" + statistics[1] + "</font>")
        if(len(statistics[2]) > 7):
            self.statistics_password.setText("Password: <font color=green>" + statistics[2][0:7] + "...</font>")
        else:
            self.statistics_password.setText("Password: <font color=green>" + statistics[2] + "</font>")



    def clear_table(self):
        self.table_index = 0
        row_number = self.credential_table.rowCount()
        column_number = self.credential_table.columnCount()

        for row in range(row_number):
            self.credential_table.removeRow(0)

        for column in range(column_number):
            self.credential_table.removeColumn(0)

        self.save_credentials.setEnabled(False)
        self.clear_credentials.setEnabled(False)


    def display_table_header(self):
        self.clear_table()
        column_headers = ("Username","Password")
        for column,header in enumerate(column_headers):
            self.credential_table.insertColumn(column)
            column_header = QtWidgets.QTableWidgetItem()
            self.credential_table.setHorizontalHeaderItem(column,column_header)
            self.credential_table.horizontalHeaderItem(column).setText(header + ' '* 5)
            self.credential_table.resizeColumnsToContents()


    def show_credentials(self,username,password):
        if(not self.credential_table.columnCount()):
            self.display_table_header()

        self.credential_table.insertRow(self.table_index)


        item = QtWidgets.QTableWidgetItem()
        self.credential_table.setItem(self.table_index,0,item)
        item.setText(str(username) + ' ' * 5)

        item = QtWidgets.QTableWidgetItem()
        self.credential_table.setItem(self.table_index,1,item)
        item.setText(str(password) + ' ' * 5)

        self.save_credentials.setEnabled(True)
        self.clear_credentials.setEnabled(True)



        self.credential_table.resizeColumnsToContents()
        self.table_index += 1


    def display_error_message(self):
        QtWidgets.QMessageBox.warning(self,"Message",self.bruteforce_core.get_exception())
        self.bruteforce_core.stop_Attack()
        self.launch_bruteforce.setText("Start")
        self.bruteforce_core.terminate()
        self.bruteforce_core.control = False
        self.start_flag = True
        self.enable_controls(True)


    def enable_controls(self,status):
        self.groupBox.setEnabled(status)
        self.settings_groupbox.setEnabled(status)
        self.custom_wordlist_groupbox.setEnabled(status)

    def save_bruteforced_credentials(self):
        target_address = str(self.target_edit.text())
        target_port = str(self.port_edit.text())
        target_service = str()

        if(self.http_https_radio.isChecked()):
            target_service = "HTTP/HTTPS (Basic Authentication)"
            target_port = str()
        if(self.telnet_radio.isChecked()):
            target_service = "TELNET"
        if(self.ftp_radio.isChecked()):
            target_service = "FTP (File Transfer Protocol)"

        file_path = QtWidgets.QFileDialog.getSaveFileName(self,"Save Credentials","report.html")[0]
        if(file_path):

            rows = self.credential_table.rowCount()
            columns = self.credential_table.columnCount()

            file_object = open(file_path,"w")
            html_header = ray_fusion_reports_html % (target_address,target_port,target_service)
            file_object.write(html_header)

            for row in range(rows):
                file_object.write("<tr>")
                for column in range(columns):
                    item = self.credential_table.item(row,column)
                    file_object.write('<td>' + str(item.text()) + '</td>')
                file_object.write("</tr>")

            file_object.write('</table></body></html>')

            file_object.flush()
            file_object.close()

            QtWidgets.QMessageBox.information(self,"Reports","Successfully saved reports to " + file_path)



    def clear_bruteforced_credentials(self):
        choice = QtWidgets.QMessageBox.question(self,"Clear Credentials","Are you sure you want to clear all bruteforced results?",QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
        if(choice == QtWidgets.QMessageBox.Yes):
            self.clear_table()
            self.save_credentials.setEnabled(False)
            self.clear_credentials.setEnabled(False)


    def Stop_Notification(self):
        self.enable_controls(True)
        self.launch_bruteforce.setText("Start")
        self.bruteforce_core.stop_Attack()
        self.start_flag = True


    def Start_Attack(self):
        self.target_address = str(self.target_edit.text())
        self.target_port = str(self.port_edit.text())
        self.time_interval = int(self.time_interval_spinbox.value())

        if(not bool(self.target_address)):
            QtWidgets.QMessageBox.warning(self,"Target Address","Please input a valid target adddress")
            self.target_edit.setFocus()
            return

        if(self.http_https_radio.isChecked()):
            self.bruteforce_core.set_attack_type("HTTP")
            valid_http = re.compile(r"^(https|http)://\S*",re.IGNORECASE)            # HTTP/HTTPS url regular expression
            if not valid_http.match(self.target_address):
                QtWidgets.QMessageBox.warning(self,"Invalid HTTP Address","The HTTP(HyperText Transfer Protocol) address should be fully qualified:\n\nExample:\nhttp://10.18.122.15\nhttps://www.foobar.com\nhttp://www.foobar.com/sports/index.html")
                return

        if(self.telnet_radio.isChecked()):
            self.bruteforce_core.set_attack_type("TELNET")
            if not self.target_port.isdigit():                                      # Check if use inputed a valid TCP port number
                QtWidgets.QMessageBox.warning(self,"Invalid Port Number","Remote Telnet Server port must be digits")
                return
            if(self.start_flag == True):
                QtWidgets.QMessageBox.warning(self,"Telnet Protocol","Please note that the Telnet protocol is very unreliable with its connection status responces, therefore the bruteforce attack on telnet might return false results as positive")

        if(self.ftp_radio.isChecked()):
            self.bruteforce_core.set_attack_type("FTP")
            if not self.target_port.isdigit():
                QtWidgets.QMessageBox.warning(self,"Invalid Port Number","Remote FTP Server port must be digits")
                return

        if(self.default_wordlist_radio.isChecked()):
            self.default_wordlist = "%s/extras/wordlists/common.txt"%(os.getcwd())       # Default Wordlist Path
            self.bruteforce_core.user_wordlist = self.default_wordlist
            self.bruteforce_core.password_wordlist = self.default_wordlist

        if(self.custom_wordlist_radio.isChecked()):
            if(not bool(self.custom_user_wordlist)):                                # Check if custom user list has been set
                QtWidgets.QMessageBox.warning(self,"Wordlist","Custom user wordlist has not been set, Please browse and select a user wordlist file of your choice")
                return
            if(not bool(self.custom_password_wordlist)):                            # Check if custom password list has been set
                QtWidgets.QMessageBox.warning(self,"Wordlist","Custom password wordlist has not been set, Please browse and select a password wordlist file of your choice")
                return

            self.bruteforce_core.user_wordlist = self.custom_user_wordlist
            self.bruteforce_core.password_wordlist = self.custom_password_wordlist

        self.bruteforce_core.empty_username = bool(self.blank_username_checkbox.isChecked())
        self.bruteforce_core.empty_password = bool(self.blank_password_checkbox.isChecked())

        self.bruteforce_core.setTimer(self.time_interval)                               # Set time in seconds
        self.bruteforce_core.set_target_address(self.target_address,self.target_port)   #

        if(self.start_flag == True):
            self.reset_objects()
            self.clear_table()
            self.enable_controls(False)
            self.launch_bruteforce.setText("Stop")
            self.start_flag = False
            self.bruteforce_core.start()
        else:
            self.enable_controls(True)
            self.launch_bruteforce.setText("Start")
            self.bruteforce_core.stop_Attack()
            self.start_flag = True










import os
import re
import tempfile
import subprocess
import shutil

from core.fern import *

############# WEP/WPA/WPS GLOBAL VARIABLES #################

#
# WPS Variables
#
wps_functions = object()        # Instance of WPS class 


#
# Network scan global variable
#
scan_control = 0
static_channel = str()
monitor_interface = str()
monitor_mac_address = str()
#
# Update checking loop (control variable)
#
updater_control = 0
xterm_setting = ''
#
# Wep Global variables
#
wep_details = {}
victim_mac = ''
victim_channel = ''
victim_access_point = ''
ivs_number = 0
WEP = ''
digit = 0
ivs_new = ivs_number + digit
#
# Wpa Global variables
#
wpa_details = {}
wpa_victim_mac_address = ''
wpa_victim_channel = ''
wpa_victim_access = ''
control = 0
current_word = ''

################### DIRECTORY GLOBAL VARIABLES ##################
#
# Creating /tmp/ directory for logging of wireless information
#

direc = tempfile.gettempdir() + os.sep
log_direc = 'fern-log'
tmp_direc = os.listdir(direc)                                    # list/tmp/
directory = os.getcwd()
temp_log_path = direc + log_direc

#
# Create temporary log directory
#
if os.path.exists(temp_log_path):
    shutil.rmtree(temp_log_path,ignore_errors=True)    # Delete directory in /fern-log if it already exists in /tmp/

os.mkdir(temp_log_path)                                 # Create /tmp/fern-log/

#
# Create Sub Temporary directory in /tmp/fern-log
#
os.mkdir(direc + 'fern-log/WPA')                                     # Create /tmp/fern-log/WPA

#
# Evecute commands without display to stdout
#
def exec_command(command,directory = None):
    output = open(os.devnull,'w')
    ret = subprocess.call(command,shell=True,stdout=output,stderr=output,cwd=directory)
    return(ret)


def is_mac_address(data):
    return bool(re.match(r'^' + r'[\:\-]'.join([r'([0-9a-f]{2})'] * 6) + r'$', data.lower()))


################## TOOL BOX VARIABLES #######################

# FERN GEOLOCATORY MAC-ADDRESS TRACKER VARIABLES

#
# Error Strings
#
database_null_error = 'There are currently no access points inserted into the database,\
Access points are added automatically after a successful attack,\
alternatively you can insert access point details manually using the\
 "Key Database" section of the main window,you can also input mac-addresses directly.\
'

invalid_mac_address_error = 'The MAC address inserted is invalid, \
a valid mac address has 6 segment with 2 hexadecimal values in each segment e.g 00:CA:56:12:8B:90'

#
# Html strings
#

# TOOLBOX OBJECTS

html_network_timeout_error = '''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Untitled Document</title>
<style type="text/css">
body,td,th {
	font-size: 12px;
}
</style>
</head>

<body>
<p><img src="file://%s/resources/map.png" alt="" width="108" height="87" /><strong> Fern GeoLocatory Mac Address Tracker
  </strong>
</p>
<p><font color="#FF0000">Network Timeout:</font></p>
<p>* The current network connection does not have access to the internet.</p>
<p>* Please check your internet connection to make sure its connected to the internet.</p>
<p>* Press the &quot;Track&quot; button when you're done.</p>
</body>
</html>
'''%(os.getcwd())

html_instructions_message = '''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Untitled Document</title>
<style type="text/css">
body,td,th {
	font-size: 12px;
}
</style>
</head>

<body>
<p><img src="file://%s/resources/map.png" alt="" width="108" height="87" /> <strong>Fern GeoLocatory Mac Address Tracker </strong></p>
<p><font color=blue>Instructions:</font></p>
<p>* Fern Geolocatory Mac Address Tracker allows you track the geographical coordinates of wifi mac-addresses.</p>
<p>* The geographical co-ordinates are retrived and the corresponding maps are displayed on this very area you are reading from.</p>
<p>* Mac-addresses can either be inserted from the list of mac-addresses in &quot;Fern Key Database&quot; or otherwise inserted manually.</p>
<p>* You can insert mac-addresses manually by using the &quot;Insert Mac Address&quot; radio button then inputing it into the combo-box.</p>
</body>
</html>
'''%(os.getcwd())




ray_fusion_reports_html = '''<html>
    <head>
        <title>Fern - Ray Fusion Report</title>
        <style type="text/css">
            h1{
                text-align: center;
            }
            h2{
                font-size: larger;
                text-decoration: underline;
            }
            .center{
                text-align: center;
                font-size: large;
            }
            #credentials{
                position: absolute;
            }

        </style>
    </head>
    <body>
        <h1>Ray Fusion Report</h1>
        <hr>
        <h2>Target Details</h2>
        <table>
            <tr>
                <td><b>Remote Address</b>:</td>
                <td>&nbsp; %s</td>
            </tr>
            <tr>
                <td><b>Remote Port</b>:</td>
                <td>&nbsp; %s</td>
            </tr>
            <tr>
                <td><b>Remote Service</b>:</td>
                <td>&nbsp; %s</td>
            </tr>
        </table>
        <hr>
        <h2 class="center">Report Details</h2>
        <table id="credentials" class="center">
            <tr>
                <td><b>Username</b></td>
                <td><b>Password</b></td>
            </tr>
'''





import os
from gui.main_window import font_size
from PyQt5 import QtCore, QtWidgets, QtGui

font_setting = font_size()


try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_ray_fusion(object):
    def setupUi(self, ray_fusion):
        ray_fusion.setObjectName(_fromUtf8("ray_fusion"))
        ray_fusion.resize(821, 572)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/fusion.png" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        ray_fusion.setWindowIcon(icon)
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(ray_fusion)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.verticalLayout_9.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.label = QtWidgets.QLabel(ray_fusion)
        self.label.setText(_fromUtf8(""))
        self.label.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Page-World.ico" % (os.getcwd()))))
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout.addWidget(self.label)
        self.target_edit = QtWidgets.QLineEdit(ray_fusion)
        self.target_edit.setMinimumSize(QtCore.QSize(281, 0))
        self.target_edit.setObjectName(_fromUtf8("target_edit"))
        self.horizontalLayout.addWidget(self.target_edit)
        self.port_edit = QtWidgets.QLineEdit(ray_fusion)
        self.port_edit.setMaximumSize(QtCore.QSize(51, 20))
        self.port_edit.setObjectName(_fromUtf8("port_edit"))
        self.horizontalLayout.addWidget(self.port_edit)
        self.horizontalLayout_4.addLayout(self.horizontalLayout)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.help_button = QtWidgets.QPushButton(ray_fusion)
        self.help_button.setText(_fromUtf8(""))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Help.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.help_button.setIcon(icon1)
        self.help_button.setIconSize(QtCore.QSize(30, 30))
        self.help_button.setFlat(True)
        self.help_button.setObjectName(_fromUtf8("help_button"))
        self.horizontalLayout_4.addWidget(self.help_button)
        self.verticalLayout_9.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName(_fromUtf8("horizontalLayout_11"))
        self.groupBox = QtWidgets.QGroupBox(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.groupBox)
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem2)
        self.http_https_radio = QtWidgets.QRadioButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.http_https_radio.setFont(font)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Page-World.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.http_https_radio.setIcon(icon2)
        self.http_https_radio.setIconSize(QtCore.QSize(20, 20))
        self.http_https_radio.setChecked(True)
        self.http_https_radio.setObjectName(_fromUtf8("http_https_radio"))
        self.horizontalLayout_2.addWidget(self.http_https_radio)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem3)
        self.telnet_radio = QtWidgets.QRadioButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.telnet_radio.setFont(font)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Application-Osx-Terminal.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.telnet_radio.setIcon(icon3)
        self.telnet_radio.setObjectName(_fromUtf8("telnet_radio"))
        self.horizontalLayout_2.addWidget(self.telnet_radio)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem4)
        self.ftp_radio = QtWidgets.QRadioButton(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.ftp_radio.setFont(font)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Ftp.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.ftp_radio.setIcon(icon4)
        self.ftp_radio.setIconSize(QtCore.QSize(20, 20))
        self.ftp_radio.setObjectName(_fromUtf8("ftp_radio"))
        self.horizontalLayout_2.addWidget(self.ftp_radio)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem5)
        self.horizontalLayout_3.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_11.addWidget(self.groupBox)
        self.settings_button = QtWidgets.QPushButton(ray_fusion)
        self.settings_button.setMaximumSize(QtCore.QSize(101, 31))
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.settings_button.setFont(font)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Setting-Tools.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.settings_button.setIcon(icon5)
        self.settings_button.setObjectName(_fromUtf8("settings_button"))
        self.horizontalLayout_11.addWidget(self.settings_button)
        self.verticalLayout_9.addLayout(self.horizontalLayout_11)
        self.settings_groupbox = QtWidgets.QGroupBox(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.settings_groupbox.setFont(font)
        self.settings_groupbox.setObjectName(_fromUtf8("settings_groupbox"))
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.settings_groupbox)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.default_wordlist_radio = QtWidgets.QRadioButton(self.settings_groupbox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.default_wordlist_radio.setFont(font)
        self.default_wordlist_radio.setChecked(True)
        self.default_wordlist_radio.setObjectName(_fromUtf8("default_wordlist_radio"))
        self.horizontalLayout_9.addWidget(self.default_wordlist_radio)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem6)
        self.custom_wordlist_radio = QtWidgets.QRadioButton(self.settings_groupbox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.custom_wordlist_radio.setFont(font)
        self.custom_wordlist_radio.setObjectName(_fromUtf8("custom_wordlist_radio"))
        self.horizontalLayout_9.addWidget(self.custom_wordlist_radio)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem7)
        self.blank_username_checkbox = QtWidgets.QCheckBox(self.settings_groupbox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.blank_username_checkbox.setFont(font)
        self.blank_username_checkbox.setChecked(True)
        self.blank_username_checkbox.setObjectName(_fromUtf8("blank_username_checkbox"))
        self.horizontalLayout_9.addWidget(self.blank_username_checkbox)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem8)
        self.blank_password_checkbox = QtWidgets.QCheckBox(self.settings_groupbox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.blank_password_checkbox.setFont(font)
        self.blank_password_checkbox.setChecked(True)
        self.blank_password_checkbox.setObjectName(_fromUtf8("blank_password_checkbox"))
        self.horizontalLayout_9.addWidget(self.blank_password_checkbox)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem9)
        self.verticalLayout_6.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.label_2 = QtWidgets.QLabel(self.settings_groupbox)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.horizontalLayout_5.addWidget(self.label_2)
        self.time_interval_spinbox = QtWidgets.QSpinBox(self.settings_groupbox)
        self.time_interval_spinbox.setObjectName(_fromUtf8("time_interval_spinbox"))
        self.horizontalLayout_5.addWidget(self.time_interval_spinbox)
        self.horizontalLayout_10.addLayout(self.horizontalLayout_5)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem10)
        self.verticalLayout_6.addLayout(self.horizontalLayout_10)
        self.verticalLayout_9.addWidget(self.settings_groupbox)
        self.custom_wordlist_groupbox = QtWidgets.QGroupBox(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.custom_wordlist_groupbox.setFont(font)
        self.custom_wordlist_groupbox.setTitle(_fromUtf8(""))
        self.custom_wordlist_groupbox.setObjectName(_fromUtf8("custom_wordlist_groupbox"))
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.custom_wordlist_groupbox)
        self.horizontalLayout_13.setObjectName(_fromUtf8("horizontalLayout_13"))
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName(_fromUtf8("horizontalLayout_12"))
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem11)
        self.user_wordlist_led = QtWidgets.QLabel(self.custom_wordlist_groupbox)
        self.user_wordlist_led.setText(_fromUtf8(""))
        self.user_wordlist_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png" % (os.getcwd()))))
        self.user_wordlist_led.setObjectName(_fromUtf8("user_wordlist_led"))
        self.horizontalLayout_12.addWidget(self.user_wordlist_led)
        self.userlist_button = QtWidgets.QPushButton(self.custom_wordlist_groupbox)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Page-White-Database.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.userlist_button.setIcon(icon6)
        self.userlist_button.setIconSize(QtCore.QSize(20, 20))
        self.userlist_button.setObjectName(_fromUtf8("userlist_button"))
        self.horizontalLayout_12.addWidget(self.userlist_button)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem12)
        self.password_wordlist_led = QtWidgets.QLabel(self.custom_wordlist_groupbox)
        self.password_wordlist_led.setText(_fromUtf8(""))
        self.password_wordlist_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png" % (os.getcwd()))))
        self.password_wordlist_led.setObjectName(_fromUtf8("password_wordlist_led"))
        self.horizontalLayout_12.addWidget(self.password_wordlist_led)
        self.passwordlist_button = QtWidgets.QPushButton(self.custom_wordlist_groupbox)
        self.passwordlist_button.setIcon(icon6)
        self.passwordlist_button.setIconSize(QtCore.QSize(20, 20))
        self.passwordlist_button.setObjectName(_fromUtf8("passwordlist_button"))
        self.horizontalLayout_12.addWidget(self.passwordlist_button)
        spacerItem13 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem13)
        self.horizontalLayout_13.addLayout(self.horizontalLayout_12)
        self.verticalLayout_9.addWidget(self.custom_wordlist_groupbox)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.label_8 = QtWidgets.QLabel(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_8.setFont(font)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.verticalLayout_8.addWidget(self.label_8)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.credential_table = QtWidgets.QTableWidget(ray_fusion)
        self.credential_table.setFrameShape(QtWidgets.QFrame.VLine)
        self.credential_table.setFrameShadow(QtWidgets.QFrame.Plain)
        self.credential_table.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.credential_table.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectItems)
        self.credential_table.setTextElideMode(QtCore.Qt.ElideRight)
        self.credential_table.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerItem)
        self.credential_table.setObjectName(_fromUtf8("credential_table"))
        self.verticalLayout_7.addWidget(self.credential_table)
        spacerItem14 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_7.addItem(spacerItem14)
        self.launch_bruteforce = QtWidgets.QPushButton(ray_fusion)
        self.launch_bruteforce.setMinimumSize(QtCore.QSize(0, 31))
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.launch_bruteforce.setFont(font)
        self.launch_bruteforce.setObjectName(_fromUtf8("launch_bruteforce"))
        self.verticalLayout_7.addWidget(self.launch_bruteforce)
        self.horizontalLayout_7.addLayout(self.verticalLayout_7)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.label_3 = QtWidgets.QLabel(ray_fusion)
        self.label_3.setMaximumSize(QtCore.QSize(52, 32))
        self.label_3.setText(_fromUtf8(""))
        self.label_3.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Statistics.ico" % (os.getcwd()))))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.horizontalLayout_6.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_4.setFont(font)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.horizontalLayout_6.addWidget(self.label_4)
        self.verticalLayout_4.addLayout(self.horizontalLayout_6)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.line_2 = QtWidgets.QFrame(ray_fusion)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName(_fromUtf8("line_2"))
        self.verticalLayout_2.addWidget(self.line_2)
        self.statistics_username = QtWidgets.QLabel(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.statistics_username.setFont(font)
        self.statistics_username.setObjectName(_fromUtf8("statistics_username"))
        self.verticalLayout_2.addWidget(self.statistics_username)
        self.statistics_password = QtWidgets.QLabel(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.statistics_password.setFont(font)
        self.statistics_password.setObjectName(_fromUtf8("statistics_password"))
        self.verticalLayout_2.addWidget(self.statistics_password)
        self.statistics_percentage = QtWidgets.QLabel(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.statistics_percentage.setFont(font)
        self.statistics_percentage.setObjectName(_fromUtf8("statistics_percentage"))
        self.verticalLayout_2.addWidget(self.statistics_percentage)
        self.verticalLayout_4.addLayout(self.verticalLayout_2)
        self.verticalLayout_3.addLayout(self.verticalLayout_4)
        self.line = QtWidgets.QFrame(ray_fusion)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.verticalLayout_3.addWidget(self.line)
        spacerItem15 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem15)
        self.save_credentials = QtWidgets.QPushButton(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.save_credentials.setFont(font)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Page-Save.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.save_credentials.setIcon(icon7)
        self.save_credentials.setIconSize(QtCore.QSize(20, 20))
        self.save_credentials.setObjectName(_fromUtf8("save_credentials"))
        self.verticalLayout_3.addWidget(self.save_credentials)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem16)
        self.clear_credentials = QtWidgets.QPushButton(ray_fusion)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.clear_credentials.setFont(font)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/Shape-Square-Delete.ico" % (os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.clear_credentials.setIcon(icon8)
        self.clear_credentials.setIconSize(QtCore.QSize(20, 20))
        self.clear_credentials.setObjectName(_fromUtf8("clear_credentials"))
        self.verticalLayout_3.addWidget(self.clear_credentials)
        spacerItem17 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem17)
        self.verticalLayout_5.addLayout(self.verticalLayout_3)
        spacerItem18 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem18)
        self.verticalLayout.addLayout(self.verticalLayout_5)
        spacerItem19 = QtWidgets.QSpacerItem(108, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout.addItem(spacerItem19)
        self.horizontalLayout_7.addLayout(self.verticalLayout)
        self.verticalLayout_8.addLayout(self.horizontalLayout_7)
        self.verticalLayout_9.addLayout(self.verticalLayout_8)

        self.retranslateUi(ray_fusion)
        QtCore.QMetaObject.connectSlotsByName(ray_fusion)
        ray_fusion.setTabOrder(self.target_edit, self.port_edit)
        ray_fusion.setTabOrder(self.port_edit, self.default_wordlist_radio)
        ray_fusion.setTabOrder(self.default_wordlist_radio, self.custom_wordlist_radio)
        ray_fusion.setTabOrder(self.custom_wordlist_radio, self.blank_username_checkbox)
        ray_fusion.setTabOrder(self.blank_username_checkbox, self.blank_password_checkbox)
        ray_fusion.setTabOrder(self.blank_password_checkbox, self.time_interval_spinbox)
        ray_fusion.setTabOrder(self.time_interval_spinbox, self.save_credentials)
        ray_fusion.setTabOrder(self.save_credentials, self.http_https_radio)
        ray_fusion.setTabOrder(self.http_https_radio, self.telnet_radio)
        ray_fusion.setTabOrder(self.telnet_radio, self.ftp_radio)
        ray_fusion.setTabOrder(self.ftp_radio, self.clear_credentials)
        ray_fusion.setTabOrder(self.clear_credentials, self.settings_button)
        ray_fusion.setTabOrder(self.settings_button, self.credential_table)
        ray_fusion.setTabOrder(self.credential_table, self.help_button)
        ray_fusion.setTabOrder(self.help_button, self.userlist_button)
        ray_fusion.setTabOrder(self.userlist_button, self.passwordlist_button)

    def retranslateUi(self, ray_fusion):
        ray_fusion.setWindowTitle(QtWidgets.QApplication.translate("ray_fusion", "Fern - Ray Fusion", None, 0))
        self.target_edit.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Insert target address here</p></body></html>", None, 0))
        self.port_edit.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Insert service port number</p></body></html>", None, 0))
        self.port_edit.setText(QtWidgets.QApplication.translate("ray_fusion", "80", None, 0))
        self.help_button.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Help</p></body></html>", None, 0))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("ray_fusion", "Service ", None, 0))
        self.http_https_radio.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>HTTP or HTTPS Service (Supports only Basic Authentication)</p></body></html>", None, 0))
        self.http_https_radio.setText(QtWidgets.QApplication.translate("ray_fusion", "HTTP / HTTPS (Basic)", None, 0))
        self.telnet_radio.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Telnet service</p></body></html>", None, 0))
        self.telnet_radio.setText(QtWidgets.QApplication.translate("ray_fusion", "TELNET", None, 0))
        self.ftp_radio.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>FTP Service</p></body></html>", None, 0))
        self.ftp_radio.setText(QtWidgets.QApplication.translate("ray_fusion", "FTP", None, 0))
        self.settings_button.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>click to hide or show settings</p></body></html>", None, 0))
        self.settings_button.setText(QtWidgets.QApplication.translate("ray_fusion", "Hide Settings", None, 0))
        self.settings_groupbox.setTitle(QtWidgets.QApplication.translate("ray_fusion", "Settings", None, 0))
        self.default_wordlist_radio.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Select to use internal wordlists</p></body></html>", None, 0))
        self.default_wordlist_radio.setText(QtWidgets.QApplication.translate("ray_fusion", "Default Wordlists", None, 0))
        self.custom_wordlist_radio.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Select to use your custom wordlists</p></body></html>", None, 0))
        self.custom_wordlist_radio.setText(QtWidgets.QApplication.translate("ray_fusion", "Custom Wordlists", None, 0))
        self.blank_username_checkbox.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Attempt blank password when bruteforcing</p></body></html>", None, 0))
        self.blank_username_checkbox.setText(QtWidgets.QApplication.translate("ray_fusion", "Attempt Blank Username", None, 0))
        self.blank_password_checkbox.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Attempt blank password when bruteforcing</p></body></html>", None, 0))
        self.blank_password_checkbox.setText(QtWidgets.QApplication.translate("ray_fusion", "Attempt Blank Password", None, 0))
        self.label_2.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Time interval between each try</p></body></html>", None, 0))
        self.label_2.setText(QtWidgets.QApplication.translate("ray_fusion", "Time Interval:", None, 0))
        self.time_interval_spinbox.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Time interval between each try</p></body></html>", None, 0))
        self.userlist_button.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Select wordlist with usernames</p></body></html>", None, 0))
        self.userlist_button.setText(QtWidgets.QApplication.translate("ray_fusion", "Import User Wordlist", None, 0))
        self.passwordlist_button.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Select wordlist with passwords</p></body></html>", None, 0))
        self.passwordlist_button.setText(QtWidgets.QApplication.translate("ray_fusion", "Import Password Wordlist", None, 0))
        self.label_8.setText(QtWidgets.QApplication.translate("ray_fusion", "Successful Login Credentials", None, 0))
        self.launch_bruteforce.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Start or Stop Bruteforce Attack</p></body></html>", None, 0))
        self.launch_bruteforce.setText(QtWidgets.QApplication.translate("ray_fusion", "Start", None, 0))
        self.label_4.setText(QtWidgets.QApplication.translate("ray_fusion", "Statistics", None, 0))
        self.statistics_username.setText(QtWidgets.QApplication.translate("ray_fusion", "Username:", None, 0))
        self.statistics_password.setText(QtWidgets.QApplication.translate("ray_fusion", "Password:", None, 0))
        self.statistics_percentage.setText(QtWidgets.QApplication.translate("ray_fusion", "0% Complete", None, 0))
        self.save_credentials.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Save credentials to disk</p></body></html>", None, 0))
        self.save_credentials.setText(QtWidgets.QApplication.translate("ray_fusion", "Save Credentials", None, 0))
        self.clear_credentials.setToolTip(QtWidgets.QApplication.translate("ray_fusion", "<html><head/><body><p>Clear all bruteforced credentials</p></body></html>", None, 0))
        self.clear_credentials.setText(QtWidgets.QApplication.translate("ray_fusion", "Clear Credentials", None, 0))

